@@ -1,7 +1,8 @@
 // SPDX-License-Identifier: BSD-3-Clause
 /* Copyright 2017-2021, Intel Corporation */
 
-#pragma once
+#ifndef LIBPMEMKV_BLACKHOLE_H
+#define LIBPMEMKV_BLACKHOLE_H
 
 #include "../engine.h"
 
@@ -60,5 +61,20 @@ private:
 	std::string name();
 };
 
+class blackhole_factory : public engine_base::factory_base {
+public:
+	std::unique_ptr<engine_base>
+	create(std::unique_ptr<internal::config> cfg) override
+	{
+		return std::unique_ptr<engine_base>(new blackhole(std::move(cfg)));
+	};
+	std::string get_name() override
+	{
+		return "blackhole";
+	};
+};
+
 } /* namespace kv */
 } /* namespace pmem */
+
+#endif /* LIBPMEMKV_BLACKHOLE_H */
