@@ -1,7 +1,8 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2017-2020, Intel Corporation */
+/* Copyright 2017-2021, Intel Corporation */
 
-#pragma once
+#ifndef LIBPMEMKV_VSMAP_H
+#define LIBPMEMKV_VSMAP_H
 
 #include "../comparator/volatile_comparator.h"
 #include "../engine.h"
@@ -78,7 +79,7 @@ private:
 };
 
 template <>
-class vsmap::vsmap_iterator<true> : virtual public internal::iterator_base {
+class vsmap::vsmap_iterator<true> : public internal::iterator_base {
 	using container_type = vsmap::map_type;
 
 public:
@@ -125,5 +126,20 @@ private:
 	std::vector<std::pair<std::string, size_t>> log;
 };
 
+class vsmap_factory : public engine_base::factory_base {
+public:
+	virtual std::unique_ptr<engine_base> create(std::unique_ptr<internal::config> cfg)
+	{
+		check_config_null(get_name(), cfg);
+		return std::unique_ptr<engine_base>(new vsmap(std::move(cfg)));
+	};
+	virtual std::string get_name()
+	{
+		return "vsmap";
+	};
+};
+
 } /* namespace kv */
 } /* namespace pmem */
+
+#endif /* LIBPMEMKV_VSMAP_H */
