@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2019, Intel Corporation */
+/* Copyright 2019-2021, Intel Corporation */
 
 #include "libpmemkv_json_config.h"
 #include "out.h"
@@ -16,9 +16,14 @@ int pmemkv_config_from_json(pmemkv_config *config, const char *json)
 	rapidjson::Document doc;
 	rapidjson::Value::ConstMemberIterator itr;
 
-	assert(config && json);
-
 	try {
+		if (!config) {
+			throw std::runtime_error("Config has to be specified");
+		}
+		if (!json) {
+			throw std::runtime_error(
+				"Configuration json has to be specified");
+		}
 		if (doc.Parse(json).HasParseError()) {
 			throw std::runtime_error("Config parsing failed");
 		}
@@ -30,7 +35,8 @@ int pmemkv_config_from_json(pmemkv_config *config, const char *json)
 					config, itr->name.GetString(), value);
 				if (status != PMEMKV_STATUS_OK)
 					throw std::runtime_error(
-						"Inserting string to the config failed");
+						"Inserting string to the config failed with error: " +
+						std::string(pmemkv_errormsg()));
 			} else if (itr->value.IsInt64()) {
 				auto value = itr->value.GetInt64();
 
@@ -38,7 +44,8 @@ int pmemkv_config_from_json(pmemkv_config *config, const char *json)
 					config, itr->name.GetString(), value);
 				if (status != PMEMKV_STATUS_OK)
 					throw std::runtime_error(
-						"Inserting int to the config failed");
+						"Inserting int to the config failed with error: " +
+						std::string(pmemkv_errormsg()));
 			} else if (itr->value.IsTrue() || itr->value.IsFalse()) {
 				auto value = itr->value.GetBool();
 
@@ -46,7 +53,8 @@ int pmemkv_config_from_json(pmemkv_config *config, const char *json)
 					config, itr->name.GetString(), value);
 				if (status != PMEMKV_STATUS_OK)
 					throw std::runtime_error(
-						"Inserting bool to the config failed");
+						"Inserting bool to the config failed with error: " +
+						std::string(pmemkv_errormsg()));
 			} else if (itr->value.IsObject()) {
 				rapidjson::StringBuffer sb;
 				rapidjson::Writer<rapidjson::StringBuffer> writer(sb);
@@ -64,7 +72,9 @@ int pmemkv_config_from_json(pmemkv_config *config, const char *json)
 				if (status != PMEMKV_STATUS_OK) {
 					pmemkv_config_delete(sub_cfg);
 					throw std::runtime_error(
-						"Cannot parse subconfig");
+						"Parsing subconfig failed with error: " +
+						std::string(
+							pmemkv_config_from_json_errormsg()));
 				}
 
 				status = pmemkv_config_put_object(
@@ -72,7 +82,8 @@ int pmemkv_config_from_json(pmemkv_config *config, const char *json)
 					(void (*)(void *)) & pmemkv_config_delete);
 				if (status != PMEMKV_STATUS_OK)
 					throw std::runtime_error(
-						"Inserting a new entry to the config failed");
+						"Inserting a new entry to the config failed with error: " +
+						std::string(pmemkv_errormsg()));
 			} else {
 				static std::string kTypeNames[] = {
 					"Null",	 "False",  "True",  "Object",
