@@ -1,11 +1,8 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2019-2020, Intel Corporation */
+/* Copyright 2019-2021, Intel Corporation */
 
 #include "unittest.h"
-#include <libpmemkv.h>
 
-#include <libpmemobj/pool_base.h>
-#include <stdlib.h>
 #include <string.h>
 
 /**
@@ -83,7 +80,7 @@ static void simple_test()
 	ret = pmemkv_config_put_size(config, SIZE);
 	UT_ASSERTeq(ret, PMEMKV_STATUS_OK);
 
-	ret = pmemkv_config_put_force_create(config, true);
+	ret = pmemkv_config_put_create_or_error_if_exists(config, true);
 	UT_ASSERTeq(ret, PMEMKV_STATUS_OK);
 
 	const char *value_string;
@@ -131,7 +128,7 @@ static void simple_test()
 	UT_ASSERTeq(ret, PMEMKV_STATUS_OK);
 	UT_ASSERTeq(value_uint, SIZE);
 
-	ret = pmemkv_config_get_uint64(config, "force_create", &value_uint);
+	ret = pmemkv_config_get_uint64(config, "create_or_error_if_exists", &value_uint);
 	UT_ASSERTeq(ret, PMEMKV_STATUS_OK);
 	UT_ASSERTeq(value_uint, 1);
 
@@ -445,4 +442,5 @@ int main(int argc, char *argv[])
 	integral_conversion_test();
 	not_found_test();
 	null_config_test();
+	return 0;
 }
