@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2020-2021, Intel Corporation */
 
 #include "unittest.hpp"
 
@@ -7,7 +7,8 @@ static void OOM(pmem::kv::db &kv)
 {
 	size_t cnt = 0;
 	while (1) {
-		auto s = kv.put(std::to_string(cnt), std::string(cnt + 1, 'a'));
+		auto s = kv.put(entry_from_number(cnt),
+				entry_from_string(std::string(cnt + 1, 'a')));
 		if (s == pmem::kv::status::OUT_OF_MEMORY)
 			break;
 
@@ -21,7 +22,7 @@ static void OOM(pmem::kv::db &kv)
 
 	/* Start freeing elements from the smallest one */
 	for (size_t i = 0; i < cnt; i++) {
-		auto s = kv.remove(std::to_string(i));
+		auto s = kv.remove(entry_from_number(i));
 		ASSERT_STATUS(s, pmem::kv::status::OK);
 	}
 
