@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2020-2021, Intel Corporation */
 
 #include "unittest.hpp"
 
@@ -14,22 +14,27 @@ static void TransactionTest(pmem::obj::pool_base &pmemobj_pool, pmem::kv::db &kv
 {
 
 	std::string value;
-	ASSERT_STATUS(kv.get("key1", &value), status::NOT_FOUND);
+	ASSERT_STATUS(kv.get(entry_from_string("key1"), &value), status::NOT_FOUND);
 
 	pmem::obj::transaction::run(pmemobj_pool, [&] {
-		ASSERT_STATUS(kv.put("key1", "value1"), status::TRANSACTION_SCOPE_ERROR);
+		ASSERT_STATUS(
+			kv.put(entry_from_string("key1"), entry_from_string("value1")),
+			status::TRANSACTION_SCOPE_ERROR);
 	});
 
 	pmem::obj::transaction::run(pmemobj_pool, [&] {
-		ASSERT_STATUS(kv.get("key1", &value), status::TRANSACTION_SCOPE_ERROR);
+		ASSERT_STATUS(kv.get(entry_from_string("key1"), &value),
+			      status::TRANSACTION_SCOPE_ERROR);
 	});
 
 	pmem::obj::transaction::run(pmemobj_pool, [&] {
-		ASSERT_STATUS(kv.remove("key1"), status::TRANSACTION_SCOPE_ERROR);
+		ASSERT_STATUS(kv.remove(entry_from_string("key1")),
+			      status::TRANSACTION_SCOPE_ERROR);
 	});
 
 	pmem::obj::transaction::run(pmemobj_pool, [&] {
-		ASSERT_STATUS(kv.exists("key1"), status::TRANSACTION_SCOPE_ERROR);
+		ASSERT_STATUS(kv.exists(entry_from_string("key1")),
+			      status::TRANSACTION_SCOPE_ERROR);
 	});
 
 	pmem::obj::transaction::run(pmemobj_pool, [&] {
