@@ -3,7 +3,7 @@
 # Copyright 2019-2021, Intel Corporation
 
 #
-# install-libpmemobj-cpp.sh <package_type>
+# install-libpmemobj-cpp.sh [package_type]
 #		- installs PMDK C++ bindings (libpmemobj-cpp)
 #
 
@@ -18,13 +18,13 @@ PREFIX="/usr"
 PACKAGE_TYPE=${1^^} #To uppercase
 echo "PACKAGE_TYPE: ${PACKAGE_TYPE}"
 
-# 1.12-rc1; 04.02.2021
-LIBPMEMOBJ_CPP_VERSION="43c174bf4c77da0d1d27dbc5eeff9a79faad2440"
+# 1.13.0-rc1 release
+LIBPMEMOBJ_CPP_VERSION="5629c29a2a998ce0c1b45db5885358c35435a7a3"
 echo "LIBPMEMOBJ_CPP_VERSION: ${LIBPMEMOBJ_CPP_VERSION}"
 
 build_dir=$(mktemp -d -t libpmemobj-cpp-XXX)
 
-git clone https://github.com/pmem/libpmemobj-cpp --shallow-since=2019-10-02 ${build_dir}
+git clone https://github.com/pmem/libpmemobj-cpp --shallow-since=2020-06-01 ${build_dir}
 
 pushd ${build_dir}
 git checkout ${LIBPMEMOBJ_CPP_VERSION}
@@ -32,7 +32,10 @@ git checkout ${LIBPMEMOBJ_CPP_VERSION}
 mkdir build
 cd build
 
-cmake .. -DCPACK_GENERATOR="${PACKAGE_TYPE}" -DCMAKE_INSTALL_PREFIX=${PREFIX}
+# turn off all redundant components
+cmake .. -DCPACK_GENERATOR="${PACKAGE_TYPE}" -DCMAKE_INSTALL_PREFIX=${PREFIX} \
+	-DBUILD_EXAMPLES=OFF -DBUILD_TESTS=OFF -DBUILD_DOC=OFF -DBUILD_BENCHMARKS=OFF \
+	-DTESTS_USE_VALGRIND=OFF
 
 if [ "${PACKAGE_TYPE}" = "" ]; then
 	make -j$(nproc) install
